@@ -2,6 +2,9 @@ from django.db import models
 from django.utils.translation import ugettext_lazy as _
 from django.core.cache import cache
 
+from flatblocks import CACHE_PREFIX
+
+
 class FlatBlock(models.Model):
     """
     Think of a flatblock as a flatpage but for just part of a site. It's
@@ -22,7 +25,7 @@ class FlatBlock(models.Model):
     def save(self):
         super(FlatBlock, self).save()
         # Now also invalidate the cache used in the templatetag
-        cache.delete('flatblocks_%s' % (self.slug, ))
+        cache.delete('%s%s' % (CACHE_PREFIX, self.slug, ))
 
     class Meta:
         verbose_name = _('Flat block')
